@@ -1,6 +1,6 @@
 /*
  * BlueALSA - bluealsa-iface.c
- * Copyright (c) 2016-2020 Arkadiusz Bokowy
+ * Copyright (c) 2016-2022 Arkadiusz Bokowy
  *
  * This file is a part of bluez-alsa.
  *
@@ -24,64 +24,10 @@ static const GDBusArgInfo arg_fd = {
 	-1, "fd", "h", NULL
 };
 
-static const GDBusArgInfo arg_path = {
-	-1, "path", "o", NULL
-};
-
-static const GDBusArgInfo arg_PCMs = {
-	-1, "PCMs", "a{oa{sv}}", NULL
-};
-
 static const GDBusArgInfo arg_props = {
 	-1, "props", "a{sv}", NULL
 };
 
-static const GDBusArgInfo *GetPCMs_out[] = {
-	&arg_PCMs,
-	NULL,
-};
-
-static const GDBusMethodInfo bluealsa_iface_manager_GetPCMs = {
-	-1, "GetPCMs",
-	NULL,
-	(GDBusArgInfo **)GetPCMs_out,
-	NULL,
-};
-
-static const GDBusMethodInfo *bluealsa_iface_manager_methods[] = {
-	&bluealsa_iface_manager_GetPCMs,
-	NULL,
-};
-
-static const GDBusArgInfo *PCMAdded_args[] = {
-	&arg_path,
-	&arg_props,
-	NULL,
-};
-
-static const GDBusArgInfo *PCMRemoved_args[] = {
-	&arg_path,
-	NULL,
-};
-
-static const GDBusSignalInfo bluealsa_iface_manager_PCMAdded = {
-	-1, "PCMAdded",
-	(GDBusArgInfo **)PCMAdded_args,
-	NULL,
-};
-
-static const GDBusSignalInfo bluealsa_iface_manager_PCMRemoved = {
-	-1, "PCMRemoved",
-	(GDBusArgInfo **)PCMRemoved_args,
-	NULL,
-};
-
-static const GDBusSignalInfo *bluealsa_iface_manager_signals[] = {
-	&bluealsa_iface_manager_PCMAdded,
-	&bluealsa_iface_manager_PCMRemoved,
-	NULL,
-};
-
 static const GDBusPropertyInfo bluealsa_iface_manager_Version = {
 	-1, "Version", "s", G_DBUS_PROPERTY_INFO_FLAGS_READABLE, NULL
 };
@@ -90,9 +36,19 @@ static const GDBusPropertyInfo bluealsa_iface_manager_Adapters = {
 	-1, "Adapters", "as", G_DBUS_PROPERTY_INFO_FLAGS_READABLE, NULL
 };
 
+static const GDBusPropertyInfo bluealsa_iface_manager_Profiles = {
+	-1, "Profiles", "as", G_DBUS_PROPERTY_INFO_FLAGS_READABLE, NULL
+};
+
+static const GDBusPropertyInfo bluealsa_iface_manager_Codecs = {
+	-1, "Codecs", "as", G_DBUS_PROPERTY_INFO_FLAGS_READABLE, NULL
+};
+
 static const GDBusPropertyInfo *bluealsa_iface_manager_properties[] = {
 	&bluealsa_iface_manager_Version,
 	&bluealsa_iface_manager_Adapters,
+	&bluealsa_iface_manager_Profiles,
+	&bluealsa_iface_manager_Codecs,
 	NULL,
 };
 
@@ -157,6 +113,10 @@ static const GDBusPropertyInfo bluealsa_iface_pcm_Mode = {
 	-1, "Mode", "s", G_DBUS_PROPERTY_INFO_FLAGS_READABLE, NULL
 };
 
+static const GDBusPropertyInfo bluealsa_iface_pcm_Running = {
+	-1, "Running", "b", G_DBUS_PROPERTY_INFO_FLAGS_READABLE, NULL
+};
+
 static const GDBusPropertyInfo bluealsa_iface_pcm_Format = {
 	-1, "Format", "q", G_DBUS_PROPERTY_INFO_FLAGS_READABLE, NULL
 };
@@ -173,6 +133,10 @@ static const GDBusPropertyInfo bluealsa_iface_pcm_Codec = {
 	-1, "Codec", "s", G_DBUS_PROPERTY_INFO_FLAGS_READABLE, NULL
 };
 
+static const GDBusPropertyInfo bluealsa_iface_pcm_CodecConfiguration = {
+	-1, "CodecConfiguration", "ay", G_DBUS_PROPERTY_INFO_FLAGS_READABLE, NULL
+};
+
 static const GDBusPropertyInfo bluealsa_iface_pcm_Delay = {
 	-1, "Delay", "q", G_DBUS_PROPERTY_INFO_FLAGS_READABLE, NULL
 };
@@ -196,10 +160,12 @@ static const GDBusPropertyInfo *bluealsa_iface_pcm_properties[] = {
 	&bluealsa_iface_pcm_Sequence,
 	&bluealsa_iface_pcm_Transport,
 	&bluealsa_iface_pcm_Mode,
+	&bluealsa_iface_pcm_Running,
 	&bluealsa_iface_pcm_Format,
 	&bluealsa_iface_pcm_Channels,
 	&bluealsa_iface_pcm_Sampling,
 	&bluealsa_iface_pcm_Codec,
+	&bluealsa_iface_pcm_CodecConfiguration,
 	&bluealsa_iface_pcm_Delay,
 	&bluealsa_iface_pcm_SoftVolume,
 	&bluealsa_iface_pcm_Volume,
@@ -228,7 +194,7 @@ static const GDBusPropertyInfo bluealsa_iface_rfcomm_Transport = {
 };
 
 static const GDBusPropertyInfo bluealsa_iface_rfcomm_Features = {
-	-1, "Features", "u", G_DBUS_PROPERTY_INFO_FLAGS_READABLE, NULL
+	-1, "Features", "as", G_DBUS_PROPERTY_INFO_FLAGS_READABLE, NULL
 };
 
 static const GDBusPropertyInfo bluealsa_iface_rfcomm_Battery = {
@@ -244,8 +210,8 @@ static const GDBusPropertyInfo *bluealsa_iface_rfcomm_properties[] = {
 
 const GDBusInterfaceInfo bluealsa_iface_manager = {
 	-1, BLUEALSA_IFACE_MANAGER,
-	(GDBusMethodInfo **)bluealsa_iface_manager_methods,
-	(GDBusSignalInfo **)bluealsa_iface_manager_signals,
+	NULL,
+	NULL,
 	(GDBusPropertyInfo **)bluealsa_iface_manager_properties,
 	NULL,
 };
