@@ -1,6 +1,6 @@
 /*
  * BlueALSA - utils.h
- * Copyright (c) 2016-2020 Arkadiusz Bokowy
+ * Copyright (c) 2016-2023 Arkadiusz Bokowy
  *
  * This file is a part of bluez-alsa.
  *
@@ -8,6 +8,7 @@
  *
  */
 
+#pragma once
 #ifndef BLUEALSA_UTILS_H_
 #define BLUEALSA_UTILS_H_
 
@@ -22,11 +23,8 @@
 
 #include <glib.h>
 
-#include "ba-transport.h"
-
 int g_dbus_bluez_object_path_to_hci_dev_id(const char *path);
 bdaddr_t *g_dbus_bluez_object_path_to_bdaddr(const char *path, bdaddr_t *addr);
-const char *g_dbus_transport_type_to_bluez_object_path(struct ba_transport_type type);
 
 char *g_variant_sanitize_object_path(char *path);
 bool g_variant_validate_value(GVariant *value, const GVariantType *type,
@@ -35,13 +33,6 @@ bool g_variant_validate_value(GVariant *value, const GVariantType *type,
 unsigned int g_bdaddr_hash(const void *v);
 gboolean g_bdaddr_equal(const void *v1, const void *v2);
 
-uint16_t ba_transport_codecs_a2dp_from_string(const char *str);
-const char *ba_transport_codecs_a2dp_to_string(uint16_t codec);
-uint16_t ba_transport_codecs_hfp_from_string(const char *str);
-const char *ba_transport_codecs_hfp_to_string(uint16_t codec);
-
-const char *ba_transport_type_to_string(struct ba_transport_type type);
-
 #if ENABLE_MP3LAME
 int a2dp_mpeg1_mp3_get_max_bitrate(uint16_t mask);
 const char *lame_encode_strerror(int err);
@@ -54,6 +45,11 @@ const char *aacdec_strerror(AAC_DECODER_ERROR err);
 const char *aacenc_strerror(AACENC_ERROR err);
 #endif
 
+#if ENABLE_LC3PLUS
+# include <lc3.h>
+const char *lc3plus_strerror(LC3PLUS_Error err);
+#endif
+
 #if ENABLE_LDAC
 const char *ldacBT_strerror(int err);
 #endif
